==> hadoop-apache-3.2.0-11-sources.jar: io/trino/hadoop/$internal/org/apache/commons/configuration2/builder/fluent/FileBasedBuilderParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.fluent;

import io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.BasicBuilderProperties;
import io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.BuilderParameters;
import io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.FileBasedBuilderProperties;

/**
 * <p>
 * Definition of a parameters interface providing a fluent API for setting all
 * properties of a configuration of a file-based configuration builder.
 * </p>
 * <p>
 * <strong>Important note:</strong> This interface is not intended to be
 * implemented by client code! It defines a set of available properties and may
 * be extended even in minor releases.
 * </p>
 *
 * @version $Id: FileBasedBuilderParameters.java 1624757 2014-09-13 15:47:43Z oheger $
 * @since 2.0
 */
public interface FileBasedBuilderParameters extends
        BasicBuilderProperties<FileBasedBuilderParameters>,
        FileBasedBuilderProperties<FileBasedBuilderParameters>,
        BuilderParameters
{
}

==> hadoop-apache-3.3.5-2-sources.jar: io/trino/hadoop/$internal/org/apache/commons/configuration2/builder/fluent/FileBasedBuilderParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.fluent;

import io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.BasicBuilderProperties;
import io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.BuilderParameters;
import io.trino.hadoop.$internal.org.apache.commons.configuration2.builder.FileBasedBuilderProperties;

/**
 * <p>
 * Definition of a parameters interface providing a fluent API for setting all properties of a configuration of a
 * file-based configuration builder.
 * </p>
 * <p>
 * <strong>Important note:</strong> This interface is not intended to be implemented by client code! It defines a set of
 * available properties and may be extended even in minor releases.
 * </p>
 *
 * @since 2.0
 */
public interface FileBasedBuilderParameters
    extends BasicBuilderProperties<FileBasedBuilderParameters>, FileBasedBuilderProperties<FileBasedBuilderParameters>, BuilderParameters {
}
